<?php
class RestUtils
{

	public static function sendResponse($status = 200, $body = '', $content_type = 'application/json')
	{
		$status_header = 'HTTP/1.1 ' . $status . ' ' . RestUtils::getStatusCodeMessage($status);
		// set the status
		header($status_header);
		// set the content type
		header('Content-type: ' . $content_type." ; charset=UTF-8");

               
		// pages with body are easy
		if($body != '')
		{
			// send the body
			echo $body;
			exit;
		}
		// we need to create the body if none is passed
		else
		{
			// create some body messages
			$message = '';

			// this is purely optional, but makes the pages a little nicer to read
			// for your users.  Since you won't likely send a lot of different status codes,
			// this also shouldn't be too ponderous to maintain
			switch($status)
			{
				case 401:
					$message = 'You must be authorized to view this page.';
					break;
				case 404:
					$message = 'The requested URL ' . $_SERVER['REQUEST_URI'] . ' was not found.';
					break;
				case 500:
					$message = 'The server encountered an error processing your request.';
					break;
				case 501:
					$message = 'The requested method is not implemented.';
					break;
			}

			// servers don't always have a signature turned on (this is an apache directive "ServerSignature On")
			$signature = ($_SERVER['SERVER_SIGNATURE'] == '') ? $_SERVER['SERVER_SOFTWARE'] . ' Server at ' . $_SERVER['SERVER_NAME'] . ' Port ' . $_SERVER['SERVER_PORT'] : $_SERVER['SERVER_SIGNATURE'];

			// this should be templatized in a real-world solution
			$body = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
						<html>
							<head>
								<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
								<title>cccc' . $status . ' ' . RestUtils::getStatusCodeMessage($status) . '</title>
							</head>
							<body>
								<h1>dsds' . RestUtils::getStatusCodeMessage($status) . '</h1>
								<p>' . $message . '</p>
								<hr />
								<address>' . $signature . '</address>
							</body>
						</html>';

			echo $body;
			exit;
		}
	}


	public static function getStatusCodeMessage($status)
	{
		// these could be stored in a .ini file and loaded
		// via parse_ini_file()... however, this will suffice
		// for an example
		$codes = Array(
		    100 => 'Continue',
		    101 => 'Switching Protocols',
		    200 => 'OK',
		    201 => 'Created',
		    202 => 'Accepted',
		    203 => 'Non-Authoritative Information',
		    204 => 'No Content',
		    205 => 'Reset Content',
		    206 => 'Partial Content',
		    300 => 'Multiple Choices',
		    301 => 'Moved Permanently',
		    302 => 'Found',
		    303 => 'See Other',
		    304 => 'Not Modified',
		    305 => 'Use Proxy',
		    306 => '(Unused)',
		    307 => 'Temporary Redirect',
		    400 => 'Bad Request',
		    401 => 'Unauthorized',
		    402 => 'Payment Required',
		    403 => 'Forbidden',
		    404 => 'Not Found',
		    405 => 'Method Not Allowed',
		    406 => 'Not Acceptable',
		    407 => 'Proxy Authentication Required',
		    408 => 'Request Timeout',
		    409 => 'Conflict',
		    410 => 'Gone',
		    411 => 'Length Required',
		    412 => 'Precondition Failed',
		    413 => 'Request Entity Too Large',
		    414 => 'Request-URI Too Long',
		    415 => 'Unsupported Media Type',
		    416 => 'Requested Range Not Satisfiable',
		    417 => 'Expectation Failed',
		    500 => 'Internal Server Error',
		    501 => 'Not Implemented',
		    502 => 'Bad Gateway',
		    503 => 'Service Unavailable',
		    504 => 'Gateway Timeout',
		    505 => 'HTTP Version Not Supported'
		);

		return (isset($codes[$status])) ? $codes[$status] : '';
	}


        public static function allowIP()
        {
           // $arrIP=array("127.0.0.1", "121.242.69.180");
            $sql="select * from wlist where ip='{$_SERVER['REMOTE_ADDR']}'";

            $result=mysql_query($sql);

            if(mysql_num_rows($result)==0)
            {
                
                $flag=false;
                $sql="select * from wlist where ip like '%*%'";
                $result=mysql_query($sql);
                if(mysql_num_rows($result)>0)
                {
                    $remoteArr=explode('.',$_SERVER['REMOTE_ADDR']);

                    while($row =  mysql_fetch_array($result))
                    {
                        $ipArr=explode(".",$row['ip']);
                        if(($remoteArr[0]==$ipArr[0])  && ($remoteArr[1]==$ipArr[1]) )
                        {
                            $flag=true;
                            break;
                        }
                        else
                        {
                            $flag=false;
                        }
                    }
                }
                if($flag==false)
                {
                    $resArray=Array("status"=>0, "message"=>"Your IP address is not allowed.");
                    $body=json_encode($resArray);
                    return self::sendResponse(401, $body);
                }
            }
        }




        public static function authenticate()
        {
//print_r(getallheaders ());
            if(!isset($_SERVER['PHP_AUTH_USER']) || !isset($_SERVER['PHP_AUTH_PW']))
            {
                $resArray=Array("status"=>0, "message"=>"Authorization credentials not found");
                $body=json_encode($resArray);
                return self::sendResponse(401, $body);
            }

            $username=$_SERVER['PHP_AUTH_USER'];
            $password=$_SERVER['PHP_AUTH_PW'];


            $student=new Student();
            
            $auth=$student->authenticateUser($username, $password);
        
           
            if($auth==false)
            {
                $resArray=Array("status"=>0, "message"=>"Invalid Credentials.");
                $body=json_encode($resArray);
                return self::sendResponse(401, $body);
            }
            else
            {
                
//                $resArray=Array("status"=>1, "message"=>"Credentials are ok");
//                $body=json_encode($resArray);
//                return self::sendResponse(200, $body);

                return $auth;
            }

            
        }
        
        public static function validateRequest()
        {
            $request_uri=$_SERVER['REQUEST_URI'];
            
            $request_uri=str_replace(BASE_DIR, "/", $request_uri);
            $arr_request=explode("/", $request_uri);

            $module=$arr_request[1];
            $action=$arr_request[2];
            if(!in_array($module, array("social")))
            {
                $resArray=Array("status"=>0, "message"=>"Bad Request");
                $body=json_encode($resArray);
                return self::sendResponse(400, $body);
            }
            

            if(!in_array($action, array("connect", "profile", "contact-list", "update-status")))
            {
                $resArray=Array("status"=>0, "message"=>"Bad Request");
                $body=json_encode($resArray);
                return self::sendResponse(400, $body);
            }
            return $arr_request;
        }

       public static function connect($id)
       {
           if($id<>"")
           {
            $resArray=Array("status"=>1, "message"=>"Ok", "id"=>$id);
            $body=json_encode($resArray);
            return self::sendResponse(200, $body);
           }
           else
           {

                $resArray=Array("status"=>0, "message"=>"Bad Request");
                $body=json_encode($resArray);
                return self::sendResponse(400, $body);
           }
       }

       public static function profile($id)
       {
           if($id<>"")
           {

            $student=new Student();
            $result=$student->profile($id);
            if($result!==false)
            {
                
                $resArray=Array("status"=>1, "message"=>"Ok", 
                    "id"=>$result['id'],
                  
                    "first_name"=>$result['First_Name'],
                    "last_name"=>$result['Last_Name'],
                    "user_name"=>$result['User_Name'],
                    "mail_address"=>$result['Mail_Address'],
                        "school"=>$result['School'],
                    "city"=>$result['City'],
                    "country" => $result['Country']
                    );
                $body=json_encode($resArray);
                return self::sendResponse(200, $body);
            }
            else
            {
                $resArray=Array("status"=>0, "message"=>"Bad Request");
                $body=json_encode($resArray);
                return self::sendResponse(400, $body);
            }
            
           }
           else
           {

                $resArray=Array("status"=>0, "message"=>"Bad Request");
                $body=json_encode($resArray);
                return self::sendResponse(400, $body);
           }
       }

        
}




class Student
{

    public function authenticateUser($username, $password)
    {
        $sql="select id, User_Name, Password  from Student where User_name='{$username}' and Password='{$password}' ";
        $result=mysql_query($sql);
        if(mysql_num_rows($result)==0)
        {
            return false;
        }
        else
        {
            $row=mysql_fetch_array($result);
            return $row['id'];
        }
    }

    public function profile($id)
    {
        $sql="select *  from Student where id='{$id}'";
        $result=mysql_query($sql);
        if(mysql_num_rows($result)==0)
        {
            return false;
        }
        else
        {
            $row=mysql_fetch_array($result);
            return $row;
        }
    }


    
}